/*
 * @file GPIO_switches.c
 * @brief Definicao das funcoes declaradas em GPIO_switches.h
 * @date Jan 13, 2023
 * @author Wu Shin-Ting
 */

#include "derivative.h"

void GPIO_initSwitchNMI (uint8_t IRQC, uint8_t prioridade) {
	/**
	 * Configura o modulo SIM: ativacao dos sinais de relogio de PORTB
	 * Ativacao dos sinais de relogio de PORTA
	 */
	*(uint32_t volatile *) 0x40048038u |= (1<<9);

	/**
	 * Configura o modulo PORTA_PCR4
	 * registrador PORTA_PCR4 mapeado em 0x40049010 
	 */
	*(uint32_t volatile *) 0x40049010u &= ~0x700; // Zera bits 10, 9 e 8 (MUX) de PTA4
	(*(uint32_t volatile *) 0x40049010u) |= 0x00000100; // Seta bit 8 do MUX de PTA4

	/**
	 * Configura o modulo GPIOA: sentido de entrada do sinal no pino PTA4, sem
	 * interrupcao habilitada
	 * registrador GPIOA_PDDR mapeado em 0x400ff014u
	 */
	(*(uint32_t volatile *) 0x400ff014u) &= ~(1<<4);

	/**
	 * Limpa flag de interrupcao do pino 4
	 * registrador PORTA_PCR4 mapeado em 0x40049010u 
	 */
	(*(uint32_t volatile *) 0x40049010u) |= (1<<24); 
			
	/**
	 * Habilita a interrupcao do pino 4 para IRQC
	 */
	*(uint32_t volatile *) 0x40049010u &= ~0xF0000; 
	(*(uint32_t volatile *) 0x40049010u) |= (IRQC << 16); 

	/**
	 * Configura o modulo NVIC: habilita IRQ 30
	 * registrador NVIC_ISER mapeado em 0xe000e100u
	 */
	(*(uint32_t volatile *) 0xe000e100u) = (1<<30);	

	/**
	 * Configura o modulo NVIC: limpa pendencias IRQ 30
	 * registrador NVIC_ICPR mapeado em 0xe000e280u
	 */
	(*(uint32_t volatile *) 0xe000e280u) = (1<<30);	

	/**
	 * Configura o modulo NVIC: seta prioriodade para IRQ30
	 * registrador NVIC_IPR7 mapeado em 0xe000e41cu (Tabela 3-7/p. 54 do Manual)
	 */
	(*(uint32_t volatile *) 0xe000e41cu) |= (prioridade<<22); 	//(Secao 3.3.2.1/p. 52 do Manual)
	
	return;
}

