/**
 * @file ISR.c
 * @brief Definicao das rotinas de servico
 * @date Jan 11, 2023
 * @author Wu Shin-Ting
 */

//Inclusao dos tipos de dados padronizados pelo ISO C99
#include "stdint.h"

//Inclusao de macros do IDE
#include "derivative.h"

//Inclusao de prototipos
#include "ISR.h"
#include "util.h"
#include "GPIO_ledRGB.h"

static uint32_t counter;

static uint32_t maxCounter;

static tipo_estado estado;

void SysTick_Handler() {
	counter++;
		
	GPIOE_PTOR = GPIO_PIN(23);     // refletir o periodo do SysTick em PTE20

	if (counter == maxCounter) {

		switch (estado) {
		case AZUL:
		case VERMELHO:
			estado = VERMELHO_VERDE;
			break;
		case VERDE:
			estado = VERDE_AMARELO;
			break;
		case AMARELO:
			estado = AMARELO_VERMELHO;
			break;
		case VERMELHO_VERDE:
		case VERDE_AMARELO:
		case AMARELO_VERMELHO:
			break;
		default:
			//erro
			break;
		}
		counter = 0;
	}
}

void ISR_resetaCounter() {
	counter = 0;
}

void ISR_setaMaxPostScaler(uint32_t valor) {
	maxCounter = valor;
}

void ISR_escreveEstado(tipo_estado valor) {
	estado = valor;
}

tipo_estado ISR_leEstado () {
	return estado;
}
