/**
 * @file main.c
 * @brief Leds verde e vermelho controlador por botoeiras IRAQA5 e NMI.
 * @author Wu Shin-Ting
 * @date 06/01/2023
 */

//Inclusao dos tipos de dados padronizados pelo ISO C99
#include "stdint.h"
//Inclusao dos prototipos
#include "util.h"
#include "GPIO_ledRGB.h"
#include "GPIO_latch_lcd.h"
#include "SysTick.h"
#include "ISR.h"

int main(void)
{
	char verde[]= "VERDE   ";
	char vermelho[9] = "VERMELHO";
	char amarelo[9] = {'A','M','A','R','E','L','O',0x00};  //0x00 = '\0'
	char azul[] = {'A','Z','U','L',' ',' ',' ',' ','\0'};  
	
	GPIO_initLedRGB();
	
	//Configura SysTick com contagem maxima 10485760 (= 0.5s)
	SysTick_init (10485760);   //periodo = 20971520*0.5 = 10485760
	SysTick_ativaInterrupt ();
	
	//Habilita conexao mcu e LCD
	GPIO_ativaConLCD ();
	//Inicializa LCD
	GPIO_initLCD();
	
	// Cria bitmaps 
	char bell[] = {0x00,0x04,0x0E,0x0E,0x0E,0x1F,0x00,0x04};
	char heart[8]={0x00,0x0A,0x15,0x11,0x0A,0x04,0x00,0x00};

	GPIO_escreveBitmapLCD (0x00, (uint8_t *)bell);
	GPIO_escreveBitmapLCD (0x01, (uint8_t *)heart);

	char bells[] = {0x00, 0x00, 0x00, '\0'};
	char hearts[] = {0x01, 0x01, 0x01, '\0'};
	
	//Habilita H5 pinos para espelhar os sinais RS, E, tempo de processamento de
	//cada byte e periodo do SysTick no analisador logico
	GPIO_initH5Pins();
	
	//Inicializa o estado do LED RGB
	//GPIO_escreveStringLCD (0x00, (uint8_t *)"AZUL    ");
	GPIO_escreveStringLCDH5Pins (0x00, (uint8_t *)azul);
	ISR_escreveEstado(AZUL);
	SysTick_resetaCVR();
	ISR_resetaCounter();
	ISR_setaMaxPostScaler (3); //1.5s
	GPIO_ledRGB(OFF, OFF, ON);
	
	for (;;) {
		switch (ISR_leEstado()) {
		case VERMELHO:
		case VERDE:
		case AMARELO:
		case AZUL:
			break;
		case VERMELHO_VERDE:
//			GPIO_escreveStringLCD (0x00, (uint8_t *)"VERDE   ");
//			GPIO_escreveStringLCD (0x40, (uint8_t *)"   ");
//			GPIO_escreveStringLCD (0x40, (uint8_t *)hearts);
			GPIO_escreveStringLCDH5Pins (0x00, (uint8_t *)verde);
			GPIO_escreveStringLCDH5Pins (0x40, (uint8_t *)"   ");
			GPIO_escreveStringLCDH5Pins (0x40, (uint8_t *)hearts);
			SysTick_resetaCVR();
			ISR_resetaCounter();
			ISR_setaMaxPostScaler (3); //1.5s
			ISR_escreveEstado (VERDE);
			GPIO_ledRGB(OFF, ON, OFF);
			break;
		case VERDE_AMARELO:
//			GPIO_escreveStringLCD (0x00, (uint8_t *)"AMARELO ");
//			GPIO_escreveStringLCD (0x40, (uint8_t *)"   ");
//			GPIO_escreveStringLCD (0x40, (uint8_t *)bells);
			GPIO_escreveStringLCDH5Pins (0x00, (uint8_t *)amarelo);
			GPIO_escreveStringLCDH5Pins (0x40, (uint8_t *)"   ");
			GPIO_escreveStringLCDH5Pins (0x40, (uint8_t *)bells);
			SysTick_resetaCVR();
			ISR_resetaCounter();
			ISR_setaMaxPostScaler (2); //1s
			ISR_escreveEstado (AMARELO);
			GPIO_ledRGB(ON, ON, OFF);
			break;
		case AMARELO_VERMELHO:
//			GPIO_escreveStringLCD (0x00, (uint8_t *)"VERMELHO");
//			GPIO_escreveStringLCD (0x40, (uint8_t *)"   ");
//			GPIO_escreveStringLCD (0x40, (uint8_t *)hearts);
			GPIO_escreveStringLCDH5Pins (0x00, (uint8_t *)vermelho);
			GPIO_escreveStringLCDH5Pins (0x40, (uint8_t *)"   ");
			GPIO_escreveStringLCDH5Pins (0x40, (uint8_t *)hearts);
			SysTick_resetaCVR();
			ISR_resetaCounter();
			ISR_setaMaxPostScaler (4);     //2s
			ISR_escreveEstado (VERMELHO);
			GPIO_ledRGB(ON, OFF, OFF);
			break;
		default:
			//erro
			break;
		}
	}

	/* Never leave main */
	return 0;
}

////////////////////////////////////////////////////////////////////////////////
// EOF
////////////////////////////////////////////////////////////////////////////////
